navigation/fatima_navigation library
Classes
- CircularRevealClipper
- CircularRevealTransition
- ConfigData
- CustomTransition
- Dependencies
- FadeInTransition
- FatimaApp
- FatimaController
- FatimaDelegate
- FatimaInformationParser
- FatimaMiddleware
- The Page Middlewares. The Functions will be called in this order (( redirect -> onPageCalled -> onBindingsStart -> onPageBuildStart -> onPageBuilt -> onPageDispose ))
-
FatimaModalBottomSheetRoute<
T> - FatimaObserver
-
FatimaPage<
T> -
FatimaPageRoute<
T> - FatimaSnackBar
- FatimaSnackBarState
-
GetBackGestureController<
T> -
GetBackGestureDetector<
T> -
GetBackGestureDetectorState<
T> - GetRouterOutlet
- LeftToRightFadeTransition
- MiddlewareRunner
- Module
- NoTransition
- PageRedirect
- PageSettings
- ParseRouteTree
- PathDecoded
- RightToLeftFadeTransition
- RouteDecoder
- RouteReport
-
RouterOutlet<
TDelegate extends RouterDelegate< T> , T extends Object> - Routing
- SizeTransitions
- SlideDownTransition
- SlideLeftTransition
- SlideRightTransition
- SlideTopTransition
- SnackbarController
- Translations
- ZoomInTransition
Enums
- PopMode
- Enables the user to customize the intended pop behavior
- PreventDuplicateHandlingMode
- Enables the user to customize the behavior when pushing multiple routes that shouldn't be duplicates
- RowStyle
- SnackbarStatus
-
Indicates Status of snackbar
SnackbarStatus.OPENSnack is fully open,SnackbarStatus.CLOSEDSnackbar has closed,SnackbarStatus.OPENINGStarts with the opening animation and ends with the full snackbar display,SnackbarStatus.CLOSINGStarts with the closing animation and ends with the full snackbar dispose - SnackPosition
-
Indicates if snack is going to start at the
TOPor at theBOTTOM - SnackStyle
- Indicates if snack will be attached to the edge of the screen or not
- Transition
Mixins
-
FatimaPageRouteTransitionMixin<
T> -
PageRouteReportMixin<
T> -
RouteReportMixin<
T extends StatefulWidget>
Extensions
Constants
-
rtlLanguages
→ const List<
String>
Properties
-
It replaces the Flutter Navigator, but needs no context.
You can to use navigator.push(YourRoute()) rather
Navigator.push(context, YourRoute());
no setter
Functions
-
removeLastHistory(
String? url) → void -
setUrlStrategy(
) → void
Typedefs
- FatimaPageBuilder = Widget Function()
-
FatimaRouteAwarePageBuilder<
T> = Widget Function([FatimaPageRoute< T> ? route]) - OnTap = void Function(FatimaSnackBar snack)
- SnackbarStatusCallback = void Function(SnackbarStatus? status)