Picture class

Inheritance
Available extensions

Constructors

Picture(dynamic src, {Key? key, double scale = 1.0, ImageFrameBuilder? frameBuilder, ImageErrorWidgetBuilder? errorBuilder, double? width, double? height, Color? color, Animation<double>? opacity, BlendMode? colorBlendMode, BoxFit? fit, ImageLoadingBuilder? loadingBuilder, FilterQuality filterQuality = FilterQuality.low, AlignmentGeometry alignment = Alignment.center, ImageRepeat repeat = ImageRepeat.noRepeat, Rect? centerSlice, bool matchTextDirection = false, Map<String, String>? headers, double? radius, Color? backgroundColor, bool circular = false})
const

Properties

alignment AlignmentGeometry
How to align the image within its bounds.
final
backgroundColor Color?
final
centerSlice Rect?
The center slice for a nine-patch image.
final
circular bool
final
color Color?
If non-null, this color is blended with each image pixel using colorBlendMode.
final
colorBlendMode BlendMode?
Used to combine color with this image.
final
errorBuilder ImageErrorWidgetBuilder?
A builder function that is called if an error occurs during image loading.
final
filterQuality FilterQuality
The rendering quality of the image.
final
fit BoxFit?
How to inscribe the image into the space allocated during layout.
final
frameBuilder ImageFrameBuilder?
final
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>?
final
height double?
If non-null, require the image to have this height.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loadingBuilder ImageLoadingBuilder?
A builder that specifies the widget to display to the user while an image is still loading.
final
marginZero Widget

Available on Widget, provided by the WidgetMarginX extension

no setter
matchTextDirection bool
Whether to paint the image in the direction of the TextDirection.
final
opacity Animation<double>?
If non-null, the value from the Animation is multiplied with the opacity of each image pixel before painting onto the canvas.
final
paddingZero Widget

Available on Widget, provided by the WidgetPaddingX extension

no setter
radius double?
final
repeat ImageRepeat
How to paint any portions of the layout bounds not covered by the image.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sliverBox Widget

Available on Widget, provided by the WidgetSliverBoxX extension

no setter
src → dynamic
final
width double?
If non-null, require the image to have this width.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
marginAll(double margin) Widget

Available on Widget, provided by the WidgetMarginX extension

marginOnly({double left = 0.0, double top = 0.0, double right = 0.0, double bottom = 0.0}) Widget

Available on Widget, provided by the WidgetMarginX extension

marginSymmetric({double horizontal = 0.0, double vertical = 0.0}) Widget

Available on Widget, provided by the WidgetMarginX extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paddingAll(double padding) Widget

Available on Widget, provided by the WidgetPaddingX extension

paddingOnly({double left = 0.0, double top = 0.0, double right = 0.0, double bottom = 0.0}) Widget

Available on Widget, provided by the WidgetPaddingX extension

paddingSymmetric({double horizontal = 0.0, double vertical = 0.0}) Widget

Available on Widget, provided by the WidgetPaddingX extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited