state_manager/fatima_state_manager library
Classes
- Bindings
-
Bindings should be extended or implemented.
When using
GetMaterialApp, allGetPages and navigation methods (like Get.to()) have abindingproperty that takes an instance of Bindings to manage the dependencies() (via Get.put()) for the Route you are opening. -
BindingsInterface<
T> - Controller
- Engine
-
FatimaView<
T> - FullLifeCycleController
- this mixin allow to fetch data when the scroll is at the bottom or on the top A controller with super lifecycles (including native lifecycles)
- ListNotifier
- ListNotifierGroup
- A notifier with group of listeners identified by id
- ListNotifierSingle
- A Notifier with single listeners
- Notifier
- NotifyData
- ObxError
- TaskManager
Mixins
- FatimaServiceMixin
- FullLifeCycleMixin
- LifeCycleMixin
- ListenableMixin
- ListNotifierGroupMixin
- ListNotifierMixin
- ListNotifierSingleMixin
- This mixin add to Listenable the addListener, removerListener and containsListener implementation
Typedefs
- BindingBuilderCallback = void Function()
- Disposer = void Function()
- GetStateUpdate = void Function()